@@ -211,6 +211,9 @@ class Stream(object):
         except socket.timeout, e:
             # 服务器是不会recv超时的
             raise e
+        except KeyboardInterrupt, e:
+            # 中断
+            raise e
         except:
             logger.error('exc occur.', exc_info=True)
             # 其他都直接关闭
@@ -225,6 +228,9 @@ class Stream(object):
     def write_to_fd(self, data):
         try:
             return self.sock.send(data)
+        except KeyboardInterrupt, e:
+            # 中断
+            raise e
         except:
             logger.error('exc occur. data: %r', data, exc_info=True)
             return None
@@ -232,6 +238,9 @@ class Stream(object):
     def close_fd(self):
         try:
             self.sock.close()
+        except KeyboardInterrupt, e:
+            # 中断
+            raise e
         except:
             logger.error('exc occur.', exc_info=True)
         finally:
@@ -240,6 +249,9 @@ class Stream(object):
     def shutdown_fd(self, how=2):
         try:
             self.sock.shutdown(how)
+        except KeyboardInterrupt, e:
+            # 中断
+            raise e
         except:
             logger.error('exc occur.', exc_info=True)
 
